@@ -123,8 +123,8 @@ AVPixelFormat decide_dst_format(AVPixelFormat src_format, bmusb::PixelFormat dst
 		if (desc->comp[0].depth != 8) continue;
 
 		// Same or better chroma resolution only.
-		int chroma_w_diff = desc->log2_chroma_w - src_desc->log2_chroma_w;
-		int chroma_h_diff = desc->log2_chroma_h - src_desc->log2_chroma_h;
+		int chroma_w_diff = src_desc->log2_chroma_w - desc->log2_chroma_w;
+		int chroma_h_diff = src_desc->log2_chroma_h - desc->log2_chroma_h;
 		if (chroma_w_diff < 0 || chroma_h_diff < 0)
 			continue;
 
