@@ -2202,7 +2202,13 @@ void Mixer::start_srt()
 	addr.sin6_family = AF_INET6;
 	addr.sin6_port = htons(global_flags.srt_port);
 
-	int err = srt_bind(sock, (sockaddr *)&addr, sizeof(addr));
+	int zero = 0;
+	int err = srt_setsockopt(sock, /*level=*/0, SRTO_IPV6ONLY, &zero, sizeof(zero));
+	if (err != 0) {
+		fprintf(stderr, "srt_setsockopt(SRTO_IPV6ONLY): %s\n", srt_getlasterror_str());
+		abort();
+	}
+	err = srt_bind(sock, (sockaddr *)&addr, sizeof(addr));
 	if (err != 0) {
 		fprintf(stderr, "srt_bind: %s\n", srt_getlasterror_str());
 		abort();
