@@ -1352,7 +1352,7 @@ void QuickSyncEncoderImpl::save_codeddata(GLSurface *surf, storage_task task)
 		}
 		if (!global_flags.x264_video_to_http &&
 		    !global_flags.av1_video_to_http) {
-			stream_mux->add_packet(pkt, task.pts + global_delay(), task.dts + global_delay());
+			http_mux->add_packet(pkt, task.pts + global_delay(), task.dts + global_delay());
 		}
 	}
 }
@@ -2045,9 +2045,9 @@ void QuickSyncEncoder::close_file()
 	impl->shutdown();
 }
 
-void QuickSyncEncoder::set_stream_mux(Mux *mux)
+void QuickSyncEncoder::set_http_mux(Mux *mux)
 {
-	impl->set_stream_mux(mux);
+	impl->set_http_mux(mux);
 }
 
 int64_t QuickSyncEncoder::global_delay() const {
