@@ -52,9 +52,9 @@ public:
 	void shutdown();
 	void close_file();
 	void release_gl_resources();
-	void set_stream_mux(Mux *mux)
+	void set_http_mux(Mux *mux)
 	{
-		stream_mux = mux;
+		http_mux = mux;
 	}
 
 	// So we never get negative dts.
@@ -174,7 +174,7 @@ private:
 	VideoCodecInterface *disk_encoder;
 	std::unique_ptr<V4LOutput> v4l_output;  // nullptr if not using V4L2 output.
 
-	Mux* stream_mux = nullptr;  // To HTTP.
+	Mux* http_mux = nullptr;  // To the HTTP server.
 	std::unique_ptr<Mux> file_mux;  // To local disk.
 
 	// Encoder parameters
