@@ -81,14 +81,14 @@ VideoEncoder::VideoEncoder(ResourcePool *resource_pool, QSurface *surface, const
 	quicksync_encoder.reset(new QuickSyncEncoder(filename, resource_pool, surface, va_display, width, height, oformat, http_encoder, disk_encoder, disk_space_estimator));
 
 	open_output_stream();
-	stream_audio_encoder->add_mux(stream_mux.get());
-	quicksync_encoder->set_stream_mux(stream_mux.get());
+	stream_audio_encoder->add_mux(http_mux.get());
+	quicksync_encoder->set_http_mux(http_mux.get());
 	if (global_flags.x264_video_to_http) {
-		x264_encoder->add_mux(stream_mux.get());
+		x264_encoder->add_mux(http_mux.get());
 	}
 #ifdef HAVE_AV1
 	if (global_flags.av1_video_to_http) {
-		av1_encoder->add_mux(stream_mux.get());
+		av1_encoder->add_mux(http_mux.get());
 	}
 #endif
 }
@@ -116,7 +116,7 @@ void VideoEncoder::do_cut(int frame)
 	// However, since this means both encoders could be sending packets at
 	// the same time, it means pts could come out of order to the stream mux,
 	// and we need to plug it until the shutdown is complete.
-	stream_mux->plug();
+	http_mux->plug();
 	lock(qs_mu, qs_audio_mu);
 	lock_guard<mutex> lock1(qs_mu, adopt_lock), lock2(qs_audio_mu, adopt_lock);
 	QuickSyncEncoder *old_encoder = quicksync_encoder.release();  // When we go C++14, we can use move capture instead.
@@ -133,7 +133,7 @@ void VideoEncoder::do_cut(int frame)
 		delete old_x264_encoder;
 		delete old_x264_disk_encoder;
 		old_encoder->close_file();
-		stream_mux->unplug();
+		http_mux->unplug();
 
 		// We cannot delete the encoder here, as this thread has no OpenGL context.
 		// We'll deal with it in begin_frame().
@@ -145,7 +145,7 @@ void VideoEncoder::do_cut(int frame)
 		x264_encoder.reset(new X264Encoder(oformat, /*use_separate_disk_params=*/false));
 		assert(global_flags.x264_video_to_http);
 		if (global_flags.x264_video_to_http) {
-			x264_encoder->add_mux(stream_mux.get());
+			x264_encoder->add_mux(http_mux.get());
 		}
 		if (overriding_bitrate != 0) {
 			x264_encoder->change_bitrate(overriding_bitrate);
@@ -159,7 +159,7 @@ void VideoEncoder::do_cut(int frame)
 	}
 
 	quicksync_encoder.reset(new QuickSyncEncoder(filename, resource_pool, surface, va_display, width, height, oformat, http_encoder, disk_encoder, disk_space_estimator));
-	quicksync_encoder->set_stream_mux(stream_mux.get());
+	quicksync_encoder->set_http_mux(http_mux.get());
 }
 
 void VideoEncoder::change_x264_bitrate(unsigned rate_kbit)
@@ -205,7 +205,7 @@ RefCountedGLsync VideoEncoder::end_frame()
 void VideoEncoder::open_output_stream()
 {
 	AVFormatContext *avctx = avformat_alloc_context();
-	avctx->oformat = const_cast<decltype(avctx->oformat)>(oformat);  // const_cast is a hack to work in FFmpeg both before and after 5.0.
+	avctx->oformat = oformat;
 
 	uint8_t *buf = (uint8_t *)av_malloc(MUX_BUFFER_SIZE);
 	avctx->pb = avio_alloc_context(buf, MUX_BUFFER_SIZE, 1, this, nullptr, nullptr, nullptr);
@@ -230,10 +230,10 @@ void VideoEncoder::open_output_stream()
 #endif
 	}
 
-	stream_mux.reset(new Mux(avctx, width, height, video_codec, video_extradata, stream_audio_encoder->get_codec_parameters().get(),
+	http_mux.reset(new Mux(avctx, width, height, video_codec, video_extradata, stream_audio_encoder->get_codec_parameters().get(),
 		get_color_space(global_flags.ycbcr_rec709_coefficients), COARSE_TIMEBASE,
-		/*write_callback=*/nullptr, Mux::WRITE_FOREGROUND, { &stream_mux_metrics }));
-	stream_mux_metrics.init({{ "destination", "http" }});
+		/*write_callback=*/nullptr, Mux::WRITE_FOREGROUND, { &http_mux_metrics }));
+	http_mux_metrics.init({{ "destination", "http" }});
 }
 
 int VideoEncoder::write_packet2_thunk(void *opaque, uint8_t *buf, int buf_size, AVIODataMarkerType type, int64_t time)
@@ -253,8 +253,8 @@ int VideoEncoder::write_packet2(uint8_t *buf, int buf_size, AVIODataMarkerType t
 	}
 
 	if (type == AVIO_DATA_MARKER_HEADER) {
-		stream_mux_header.append((char *)buf, buf_size);
-		httpd->set_header(HTTPD::StreamID{ HTTPD::MAIN_STREAM, 0 }, stream_mux_header);
+		http_mux_header.append((char *)buf, buf_size);
+		httpd->set_header(HTTPD::StreamID{ HTTPD::MAIN_STREAM, 0 }, http_mux_header);
 	} else {
 		httpd->add_data(HTTPD::StreamID{ HTTPD::MAIN_STREAM, 0 }, (char *)buf, buf_size, type == AVIO_DATA_MARKER_SYNC_POINT, time, AVRational{ AV_TIME_BASE, 1 });
 	}
