@@ -91,7 +91,7 @@ private:
 
 	bool seen_sync_markers = false;
 
-	std::unique_ptr<Mux> stream_mux;  // To HTTP.
+	std::unique_ptr<Mux> http_mux;  // To the HTTP server.
 	std::unique_ptr<AudioEncoder> stream_audio_encoder;
 	std::unique_ptr<X264Encoder> x264_encoder;  // nullptr if not using x264.
 	std::unique_ptr<X264Encoder> x264_disk_encoder;  // nullptr if not using x264, or if not having separate disk encodes.
@@ -99,8 +99,8 @@ private:
 	std::unique_ptr<AV1Encoder> av1_encoder;  // nullptr if not using SVT-AV1.
 #endif
 
-	std::string stream_mux_header;
-	MuxMetrics stream_mux_metrics;
+	std::string http_mux_header;
+	MuxMetrics http_mux_metrics;
 
 	std::atomic<int> quicksync_encoders_in_shutdown{0};
 	std::atomic<int> overriding_bitrate{0};
