@@ -50,7 +50,7 @@ class Mux {
 public:
 	enum Codec {
 		CODEC_H264,
-		CODEC_NV12,  // Uncompressed 4:2:0.
+		CODEC_AV1,
 		CODEC_MJPEG
 	};
 	enum WriteStrategy {
